import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 890;
const height = 450;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;
const eyeOffsetX = 70;
const eyeOffsetY = 80;
const ellipseX = 45;
const ellipseY = 25;
const eyeRadius = 25;
const noseRadius = 30;
const noseWidth = 10;
const mouthWidth = 20;
const mouthRadius = 120;

const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth-5)
  .startAngle((Math.PI / 2) + 0.4)
  .endAngle((Math.PI * 2) / 1.5);

const noseArc = arc()
   .innerRadius(noseRadius)
   .outerRadius(noseRadius + noseWidth)
   .startAngle(Math.PI / 2)
   .endAngle(Math.PI * 3/2);

const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      <circle
        r={(centerY/1.1) - (strokeWidth / 2)}
        fill="tan"
        stroke="black"
        stroke-width={strokeWidth-15}
      />
      
      <circle 
        cx={-eyeOffsetX-10} 
        cy={-eyeOffsetY+55}
        r={4}
      />
      <circle
        cx={-eyeOffsetX-30}
        cy={-eyeOffsetY+60}
        r={4}
      />
      <circle
        cx={-eyeOffsetX-30}
        cy={-eyeOffsetY+80}
        r={4}
      />
      <circle
        cx={-eyeOffsetX-10}
        cy={-eyeOffsetY+80}
        r={4}
      />
      <circle
        cx={-eyeOffsetX-10}
        cy={-eyeOffsetY+55}
        r={4}
      />
      <circle
        cx={-eyeOffsetX+150}
        cy={-eyeOffsetY+77}
        r={4}
      />
      <circle
        cx={-eyeOffsetX +150}
        cy={-eyeOffsetY+55}
        r={4}
        fill="black"
      />
      <circle
        cx={-eyeOffsetX+130}
        cy={-eyeOffsetY+80}
        r={4}
      />
      <circle
        cx={-eyeOffsetX+130}
        cy={-eyeOffsetY+60}
        r={4}
      />
    
      <path d="M -180 -95 q 160 -200 370 0" 
        stroke="black" stroke-width="8" fill="none" />
      <path d="M -180 -86 q 160 -200 370 0" 
       stroke="black" stroke-width="8" fill="none" />
      <path d="M -180 -76 q 160 -200 370 0" 
       stroke="black" stroke-width="8" fill="none" />
      <path d="M -150 -56 q 100 -130 130 0" 
       stroke="black" stroke-width="8" fill="none" />      
      <path d="M 0 -56 q 100 -130 120 0" 
       stroke="black" stroke-width="8" fill="none" /> 
      
       <path d="M -95 85 q 100 115 195 3" 
       stroke="black" stroke-width="8" fill="none" />
      
      <ellipse
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        rx={ellipseX}
        ry={ellipseY}
        fill="white"
        stroke="black"
        stroke-width={strokeWidth - 13}
      />
      <circle
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius - 5}
        fill="green"
        stroke="black"
        stroke-width= {strokeWidth - 16}
      />

      <ellipse
        cx={eyeOffsetX}
        cy={-eyeOffsetY}
        rx={ellipseX}
        ry={ellipseY}
        fill="white"
        stroke="black"
        stroke-width={strokeWidth - 13}
      />
      <circle 
        cx={eyeOffsetX} 
        cy={-eyeOffsetY} 
        r={eyeRadius - 5}
        fill="green"
        stroke="black"
        stroke-width= {strokeWidth - 16}
      />
      <path d={noseArc()} />
      <path d={mouthArc()} />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);